import 'dart:io';
import 'dart:typed_data';

import 'package:flutter/material.dart';
import 'package:vaycore/utils.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-20
///

/// 头像组件
class Avatar extends StatelessWidget {
  final Image _image;
  final Color borderColor;
  final double borderWidth;
  final EdgeInsetsGeometry margin;

  Avatar.network(String src,
      {Key key,
      double size,
      BoxFit fit = BoxFit.cover,
      this.borderColor,
      this.borderWidth,
      this.margin})
      : _image = Image.network(
          src,
          width: size,
          height: size,
          fit: fit,
        ),
        super(key: key);

  Avatar.asset(String name,
      {Key key,
      double size,
      BoxFit fit = BoxFit.cover,
      this.borderColor,
      this.borderWidth,
      this.margin})
      : _image = Image.asset(
          name,
          width: size,
          height: size,
          fit: fit,
        ),
        super(key: key);

  Avatar.file(File file,
      {Key key,
      double size,
      BoxFit fit = BoxFit.cover,
      this.borderColor,
      this.borderWidth,
      this.margin})
      : _image = Image.file(
          file,
          width: size,
          height: size,
          fit: fit,
        ),
        super(key: key);

  Avatar.memory(Uint8List bytes,
      {Key key,
      double size,
      BoxFit fit = BoxFit.cover,
      this.borderColor,
      this.borderWidth,
      this.margin})
      : _image = Image.memory(
          bytes,
          width: size,
          height: size,
          fit: fit,
        ),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        shape: BoxShape.circle,
        color: this.borderColor ?? Colors.transparent,
      ),
      padding: EdgeInsets.all(this.borderWidth ?? 0),
      margin: this.margin ?? EdgeInsets.all(0),
      child: ClipOval(
        child: WidgetUtils.notNull(this._image),
      ),
    );
  }
}
