import 'package:flutter/material.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-24
///

/// 价格组件
class Price extends StatelessWidget {
  /// 价格
  final String value;

  /// 价格字体颜色
  final Color valueColor;

  /// 价格字体大小
  final double valueSize;

  /// 价格字体加粗
  final FontWeight valueBold;

  /// 价格字体样式
  final TextStyle valueStyle;

  /// 单位
  final String unit;

  /// 单位字体颜色
  final Color unitColor;

  /// 单位字体大小
  final double unitSize;

  /// 单位字体加粗
  final FontWeight unitBold;

  /// 单位字体样式
  final TextStyle unitStyle;

  /// 整体字体颜色
  final Color color;

  /// 整体字体大小
  final double fontSize;

  /// 整体字体加粗效果
  final FontWeight bold;

  /// 删除线
  final bool deleted;

  /// 删除线颜色
  final Color deletedColor;

  Price({
    Key key,
    this.value,
    this.valueColor,
    this.valueSize,
    this.valueBold,
    this.valueStyle,
    this.unit = "￥",
    this.unitColor,
    this.unitSize,
    this.unitBold,
    this.unitStyle,
    this.deleted = false,
    this.deletedColor = Colors.black,
    this.color = Colors.black,
    this.fontSize = 12,
    this.bold = FontWeight.normal,
  }) : super(key: key);

  /// 基础样式
  TextStyle _baseStyle() => TextStyle(
        color: this.color,
        fontSize: this.fontSize,
        fontWeight: this.bold,
      );

  /// 添加删除线
  TextStyle _addDeletedStyle(TextStyle style) {
    if (style == null || !this.deleted) {
      return style;
    }
    return style.copyWith(
      decoration: TextDecoration.lineThrough,
      decorationColor: this.deletedColor,
    );
  }

  /// 单位样式
  TextStyle _unitStyle() {
    TextStyle unitStyle = this.unitStyle;
    if (unitStyle == null) {
      unitStyle = _baseStyle();
      // 单属性优先级大于整体属性优先级
      if (this.unitColor != null) {
        unitStyle = unitStyle.copyWith(color: this.unitColor);
      }
      if (this.unitSize != null) {
        unitStyle = unitStyle.copyWith(fontSize: this.unitSize);
      }
      if (this.unitBold != null) {
        unitStyle = unitStyle.copyWith(fontWeight: this.unitBold);
      }
    }
    return _addDeletedStyle(unitStyle);
  }

  /// 价格样式
  TextStyle _valueStyle() {
    TextStyle valueStyle = this.valueStyle;
    if (valueStyle == null) {
      valueStyle = _baseStyle();
      // 单属性优先级大于整体属性优先级
      if (this.valueColor != null) {
        valueStyle = valueStyle.copyWith(color: this.valueColor);
      }
      if (this.valueSize != null) {
        valueStyle = valueStyle.copyWith(fontSize: this.valueSize);
      }
      if (this.valueBold != null) {
        valueStyle = valueStyle.copyWith(fontWeight: this.valueBold);
      }
    }
    return _addDeletedStyle(valueStyle);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.end,
        children: <Widget>[
          Text(
            this.unit,
            style: _unitStyle(),
          ),
          Text(
            this.value,
            style: _valueStyle(),
          )
        ],
      ),
    );
  }
}
